@@ -6,7 +6,7 @@
 /*                                                                          */
 /*                              C Header File                               */
 /*                                                                          */
-/*                            $Revision: 1.46 $                             */
+/*                            $Revision: 1.50 $                             */
 /*                                                                          */
 /*          Copyright (C) 1992-1997, Free Software Foundation, Inc.         */
 /*                                                                          */
@@ -34,9 +34,73 @@
    Note that only routines for reading the tree are included, since the tree
    transformer is not supposed to modify the tree in any way. */
 
-/* Structure used for extra flags in third component overlaying Nkind */
-struct Flag_Byte
+/* Structure used for the first part of the node in the case where we have
+   an Nkind.  */
+
+struct NFK
 {
+  Boolean      is_extension      :  1;
+  Boolean      pflag1            :  1;
+  Boolean      pflag2            :  1;
+  Boolean      in_list           :  1;
+  Boolean      rewrite_sub       :  1;
+  Boolean      rewrite_ins       :  1;
+  Boolean      analyzed          :  1;
+  Boolean      comes_from_source :  1;
+
+  Boolean      error_posted  :  1;
+  Boolean      flag4  :  1;
+  Boolean      flag5  :  1;
+  Boolean      flag6  :  1;
+  Boolean      flag7  :  1;
+  Boolean      flag8  :  1;
+  Boolean      flag9  :  1;
+  Boolean      flag10 :  1;
+
+  Boolean      flag11 :  1;
+  Boolean      flag12 :  1;
+  Boolean      flag13 :  1;
+  Boolean      flag14 :  1;
+  Boolean      flag15 :  1;
+  Boolean      flag16 :  1;
+  Boolean      flag17 :  1;
+  Boolean      flag18 :  1;
+
+  unsigned char kind;
+};
+
+/* Structure for the first part of a node when Nkind is not present by
+   extra flag bits are.  */
+
+struct NFNK
+{
+  Boolean      is_extension      :  1;
+  Boolean      pflag1            :  1;
+  Boolean      pflag2            :  1;
+  Boolean      in_list           :  1;
+  Boolean      rewrite_sub       :  1;
+  Boolean      rewrite_ins       :  1;
+  Boolean      analyzed          :  1;
+  Boolean      comes_from_source :  1;
+
+  Boolean      error_posted  :  1;
+  Boolean      flag4  :  1;
+  Boolean      flag5  :  1;
+  Boolean      flag6  :  1;
+  Boolean      flag7  :  1;
+  Boolean      flag8  :  1;
+  Boolean      flag9  :  1;
+  Boolean      flag10 :  1;
+
+  Boolean      flag11 :  1;
+  Boolean      flag12 :  1;
+  Boolean      flag13 :  1;
+  Boolean      flag14 :  1;
+  Boolean      flag15 :  1;
+  Boolean      flag16 :  1;
+  Boolean      flag17 :  1;
+  Boolean      flag18 :  1;
+
   Boolean      flag65	    :  1;
   Boolean      flag66	    :  1;
   Boolean      flag67	    :  1;
@@ -114,6 +178,23 @@ struct Flag_Word2
   Boolean      flag128	    :  1;
 };
 
+/* Structure used for extra flags in fourth component overlaying Field11 */
+struct Flag_Word3
+{
+  Boolean      flag152	    :  1;
+  Boolean      flag153	    :  1;
+  Boolean      flag154	    :  1;
+  Boolean      flag155	    :  1;
+  Boolean      flag156	    :  1;
+  Boolean      flag157	    :  1;
+  Boolean      flag158	    :  1;
+  Boolean      flag159	    :  1;
+
+  char         filler1      :  8;
+  char         filler2      :  8;
+  char         filler3      :  8;
+};
+
 struct Non_Extended
 {
   Source_Ptr   sloc;
@@ -133,7 +214,12 @@ struct Extended
   Int	       field8;
   Int	       field9;
   Int	       field10;
-  Int	       field11;
+  union     
+    {
+      Int      field11;
+      struct Flag_Word3 fw3;
+    } X;
+
   union
     {
       Int      field12;
@@ -146,37 +232,10 @@ struct Extended
 
 struct Node
 {
-  Boolean      is_extension      :  1;
-  Boolean      pflag1            :  1;
-  Boolean      pflag2            :  1;
-  Boolean      in_list           :  1;
-  Boolean      rewrite_sub       :  1;
-  Boolean      rewrite_ins       :  1;
-  Boolean      analyzed          :  1;
-  Boolean      comes_from_source :  1;
-
-  Boolean      error_posted  :  1;
-  Boolean      flag4  :  1;
-  Boolean      flag5  :  1;
-  Boolean      flag6  :  1;
-  Boolean      flag7  :  1;
-  Boolean      flag8  :  1;
-  Boolean      flag9  :  1;
-  Boolean      flag10 :  1;
-
-  Boolean      flag11 :  1;
-  Boolean      flag12 :  1;
-  Boolean      flag13 :  1;
-  Boolean      flag14 :  1;
-  Boolean      flag15 :  1;
-  Boolean      flag16 :  1;
-  Boolean      flag17 :  1;
-  Boolean      flag18 :  1;
-
-  union
+  union kind
     {
-      unsigned char kind;
-      struct Flag_Byte fb;
+      struct NFK K;
+      struct NFNK NK;
     } U;
 
   union variant
@@ -227,10 +286,11 @@ extern Node_Id Parent		PROTO((Tree_Id));
 
 /* Node Access Functions:  */
 
-#define Nkind(N)        ((Node_Kind)(Nodes_Ptr [N].U.kind))
-#define Ekind(N)        ((Entity_Kind)(Nodes_Ptr [N + 1].U.kind))
+#define Nkind(N)        ((Node_Kind)(Nodes_Ptr [N].U.K.kind))
+#define Ekind(N)        ((Entity_Kind)(Nodes_Ptr [N + 1].U.K.kind))
 #define Sloc(N)         (Nodes_Ptr [N].V.NX.sloc)
-#define Paren_Count (N) (Nodes_Ptr [N].Pflag1 + 2 * Nodes_Ptr [N].Pflag2)
+#define Paren_Count(N)	(Nodes_Ptr [N].U.K.pflag1	\
+			 + 2 * Nodes_Ptr [N].U.K.pflag2)
 
 #define Field1(N)     (Nodes_Ptr [N].V.NX.field1)
 #define Field2(N)     (Nodes_Ptr [N].V.NX.field2)
@@ -242,14 +302,14 @@ extern Node_Id Parent		PROTO((Tree_Id));
 #define Field8(N)     (Nodes_Ptr [N+1].V.EX.field8)
 #define Field9(N)     (Nodes_Ptr [N+1].V.EX.field9)
 #define Field10(N)    (Nodes_Ptr [N+1].V.EX.field10)
-#define Field11(N)    (Nodes_Ptr [N+1].V.EX.field11)
+#define Field11(N)    (Nodes_Ptr [N+1].V.EX.X.field11)
 #define Field12(N)    (Nodes_Ptr [N+1].V.EX.U.field12)
 #define Field13(N)    (Nodes_Ptr [N+2].V.EX.field6)
 #define Field14(N)    (Nodes_Ptr [N+2].V.EX.field7)
 #define Field15(N)    (Nodes_Ptr [N+2].V.EX.field8)
 #define Field16(N)    (Nodes_Ptr [N+2].V.EX.field9)
 #define Field17(N)    (Nodes_Ptr [N+2].V.EX.field10)
-#define Field18(N)    (Nodes_Ptr [N+2].V.EX.field11)
+#define Field18(N)    (Nodes_Ptr [N+2].V.EX.X.field11)
 #define Field19(N)    (Nodes_Ptr [N+3].V.EX.field6)
 #define Field20(N)    (Nodes_Ptr [N+3].V.EX.field7)
 #define Field21(N)    (Nodes_Ptr [N+3].V.EX.field8)
@@ -266,14 +326,14 @@ extern Node_Id Parent		PROTO((Tree_Id));
 #define Node8(N)      (Nodes_Ptr [N+1].V.EX.field8)
 #define Node9(N)      (Nodes_Ptr [N+1].V.EX.field9)
 #define Node10(N)     (Nodes_Ptr [N+1].V.EX.field10)
-#define Node11(N)     (Nodes_Ptr [N+1].V.EX.field11)
+#define Node11(N)     (Nodes_Ptr [N+1].V.EX.X.field11)
 #define Node12(N)     (Nodes_Ptr [N+1].V.EX.U.field12)
 #define Node13(N)     (Nodes_Ptr [N+2].V.EX.field6)
 #define Node14(N)     (Nodes_Ptr [N+2].V.EX.field7)
 #define Node15(N)     (Nodes_Ptr [N+2].V.EX.field8)
 #define Node16(N)     (Nodes_Ptr [N+2].V.EX.field9)
 #define Node17(N)     (Nodes_Ptr [N+2].V.EX.field10)
-#define Node18(N)     (Nodes_Ptr [N+2].V.EX.field11)
+#define Node18(N)     (Nodes_Ptr [N+2].V.EX.X.field11)
 #define Node19(N)     (Nodes_Ptr [N+3].V.EX.field6)
 #define Node20(N)     (Nodes_Ptr [N+3].V.EX.field7)
 #define Node21(N)     (Nodes_Ptr [N+3].V.EX.field8)
@@ -291,6 +351,7 @@ extern Node_Id Parent		PROTO((Tree_Id));
 #define Elist7(N)     (Nodes_Ptr [N+1].V.EX.field7)
 #define Elist13(N)    (Nodes_Ptr [N+2].V.EX.field6)
 #define Elist14(N)    (Nodes_Ptr [N+2].V.EX.field7)
+#define Elist19(N)    (Nodes_Ptr [N+3].V.EX.field6)
 
 #define Name1(N)      (Nodes_Ptr [N].V.NX.field1)
 #define Name2(N)      (Nodes_Ptr [N].V.NX.field2)
@@ -303,7 +364,7 @@ extern Node_Id Parent		PROTO((Tree_Id));
 #define Uint4(N)      (Nodes_Ptr [N].V.NX.field4)
 #define Uint8(N)      (Nodes_Ptr [N+1].V.EX.field8)
 #define Uint9(N)      (Nodes_Ptr [N+1].V.EX.field9)
-#define Uint11(N)     (Nodes_Ptr [N+1].V.EX.field11)
+#define Uint11(N)     (Nodes_Ptr [N+1].V.EX.X.field11)
 #define Uint12(N)     (Nodes_Ptr [N+1].V.EX.U.field12)
 #define Uint13(N)     (Nodes_Ptr [N+2].V.EX.field6)
 #define Uint15(N)     (Nodes_Ptr [N+2].V.EX.field8)
@@ -314,82 +375,82 @@ extern Node_Id Parent		PROTO((Tree_Id));
 #define Ureal6(N)     (Nodes_Ptr [N+1].V.EX.field6)
 #define Ureal7(N)     (Nodes_Ptr [N+1].V.EX.field7)
 
-#define Analyzed(N)          (Nodes_Ptr [N].analyzed)
-#define Comes_From_Source(N) (Nodes_Ptr [N].comes_from_source)
-#define Error_Posted(N)      (Nodes_Ptr [N].error_posted)
+#define Analyzed(N)          (Nodes_Ptr [N].U.K.analyzed)
+#define Comes_From_Source(N) (Nodes_Ptr [N].U.K.comes_from_source)
+#define Error_Posted(N)      (Nodes_Ptr [N].U.K.error_posted)
 
-#define Flag4(N)      (Nodes_Ptr [N].flag4)
-#define Flag5(N)      (Nodes_Ptr [N].flag5)
-#define Flag6(N)      (Nodes_Ptr [N].flag6)
-#define Flag7(N)      (Nodes_Ptr [N].flag7)
-#define Flag8(N)      (Nodes_Ptr [N].flag8)
-#define Flag9(N)      (Nodes_Ptr [N].flag9)
-#define Flag10(N)     (Nodes_Ptr [N].flag10)
-#define Flag11(N)     (Nodes_Ptr [N].flag11)
-#define Flag12(N)     (Nodes_Ptr [N].flag12)
-#define Flag13(N)     (Nodes_Ptr [N].flag13)
-#define Flag14(N)     (Nodes_Ptr [N].flag14)
-#define Flag15(N)     (Nodes_Ptr [N].flag15)
-#define Flag16(N)     (Nodes_Ptr [N].flag16)
-#define Flag17(N)     (Nodes_Ptr [N].flag17)
-#define Flag18(N)     (Nodes_Ptr [N].flag18)
+#define Flag4(N)      (Nodes_Ptr [N].U.K.flag4)
+#define Flag5(N)      (Nodes_Ptr [N].U.K.flag5)
+#define Flag6(N)      (Nodes_Ptr [N].U.K.flag6)
+#define Flag7(N)      (Nodes_Ptr [N].U.K.flag7)
+#define Flag8(N)      (Nodes_Ptr [N].U.K.flag8)
+#define Flag9(N)      (Nodes_Ptr [N].U.K.flag9)
+#define Flag10(N)     (Nodes_Ptr [N].U.K.flag10)
+#define Flag11(N)     (Nodes_Ptr [N].U.K.flag11)
+#define Flag12(N)     (Nodes_Ptr [N].U.K.flag12)
+#define Flag13(N)     (Nodes_Ptr [N].U.K.flag13)
+#define Flag14(N)     (Nodes_Ptr [N].U.K.flag14)
+#define Flag15(N)     (Nodes_Ptr [N].U.K.flag15)
+#define Flag16(N)     (Nodes_Ptr [N].U.K.flag16)
+#define Flag17(N)     (Nodes_Ptr [N].U.K.flag17)
+#define Flag18(N)     (Nodes_Ptr [N].U.K.flag18)
 
-#define Flag19(N)     (Nodes_Ptr [N+1].in_list)
-#define Flag20(N)     (Nodes_Ptr [N+1].rewrite_sub)
-#define Flag21(N)     (Nodes_Ptr [N+1].rewrite_ins)
-#define Flag22(N)     (Nodes_Ptr [N+1].analyzed)
-#define Flag23(N)     (Nodes_Ptr [N+1].comes_from_source)
-#define Flag24(N)     (Nodes_Ptr [N+1].error_posted)
-#define Flag25(N)     (Nodes_Ptr [N+1].flag4)
-#define Flag26(N)     (Nodes_Ptr [N+1].flag5)
-#define Flag27(N)     (Nodes_Ptr [N+1].flag6)
-#define Flag28(N)     (Nodes_Ptr [N+1].flag7)
-#define Flag29(N)     (Nodes_Ptr [N+1].flag8)
-#define Flag30(N)     (Nodes_Ptr [N+1].flag9)
-#define Flag31(N)     (Nodes_Ptr [N+1].flag10)
-#define Flag32(N)     (Nodes_Ptr [N+1].flag11)
-#define Flag33(N)     (Nodes_Ptr [N+1].flag12)
-#define Flag34(N)     (Nodes_Ptr [N+1].flag13)
-#define Flag35(N)     (Nodes_Ptr [N+1].flag14)
-#define Flag36(N)     (Nodes_Ptr [N+1].flag15)
-#define Flag37(N)     (Nodes_Ptr [N+1].flag16)
-#define Flag38(N)     (Nodes_Ptr [N+1].flag17)
-#define Flag39(N)     (Nodes_Ptr [N+1].flag18)
+#define Flag19(N)     (Nodes_Ptr [N+1].U.K.in_list)
+#define Flag20(N)     (Nodes_Ptr [N+1].U.K.rewrite_sub)
+#define Flag21(N)     (Nodes_Ptr [N+1].U.K.rewrite_ins)
+#define Flag22(N)     (Nodes_Ptr [N+1].U.K.analyzed)
+#define Flag23(N)     (Nodes_Ptr [N+1].U.K.comes_from_source)
+#define Flag24(N)     (Nodes_Ptr [N+1].U.K.error_posted)
+#define Flag25(N)     (Nodes_Ptr [N+1].U.K.flag4)
+#define Flag26(N)     (Nodes_Ptr [N+1].U.K.flag5)
+#define Flag27(N)     (Nodes_Ptr [N+1].U.K.flag6)
+#define Flag28(N)     (Nodes_Ptr [N+1].U.K.flag7)
+#define Flag29(N)     (Nodes_Ptr [N+1].U.K.flag8)
+#define Flag30(N)     (Nodes_Ptr [N+1].U.K.flag9)
+#define Flag31(N)     (Nodes_Ptr [N+1].U.K.flag10)
+#define Flag32(N)     (Nodes_Ptr [N+1].U.K.flag11)
+#define Flag33(N)     (Nodes_Ptr [N+1].U.K.flag12)
+#define Flag34(N)     (Nodes_Ptr [N+1].U.K.flag13)
+#define Flag35(N)     (Nodes_Ptr [N+1].U.K.flag14)
+#define Flag36(N)     (Nodes_Ptr [N+1].U.K.flag15)
+#define Flag37(N)     (Nodes_Ptr [N+1].U.K.flag16)
+#define Flag38(N)     (Nodes_Ptr [N+1].U.K.flag17)
+#define Flag39(N)     (Nodes_Ptr [N+1].U.K.flag18)
 
-#define Flag40(N)     (Nodes_Ptr [N+2].in_list)
-#define Flag41(N)     (Nodes_Ptr [N+2].rewrite_sub)
-#define Flag42(N)     (Nodes_Ptr [N+2].rewrite_ins)
-#define Flag43(N)     (Nodes_Ptr [N+2].analyzed)
-#define Flag44(N)     (Nodes_Ptr [N+2].comes_from_source)
-#define Flag45(N)     (Nodes_Ptr [N+2].error_posted)
-#define Flag46(N)     (Nodes_Ptr [N+2].flag4)
-#define Flag47(N)     (Nodes_Ptr [N+2].flag5)
-#define Flag48(N)     (Nodes_Ptr [N+2].flag6)
-#define Flag49(N)     (Nodes_Ptr [N+2].flag7)
-#define Flag50(N)     (Nodes_Ptr [N+2].flag8)
-#define Flag51(N)     (Nodes_Ptr [N+2].flag9)
-#define Flag52(N)     (Nodes_Ptr [N+2].flag10)
-#define Flag53(N)     (Nodes_Ptr [N+2].flag11)
-#define Flag54(N)     (Nodes_Ptr [N+2].flag12)
-#define Flag55(N)     (Nodes_Ptr [N+2].flag13)
-#define Flag56(N)     (Nodes_Ptr [N+2].flag14)
-#define Flag57(N)     (Nodes_Ptr [N+2].flag15)
-#define Flag58(N)     (Nodes_Ptr [N+2].flag16)
-#define Flag59(N)     (Nodes_Ptr [N+2].flag17)
-#define Flag60(N)     (Nodes_Ptr [N+2].flag18)
-#define Flag61(N)     (Nodes_Ptr [N+1].pflag1)
-#define Flag62(N)     (Nodes_Ptr [N+1].pflag2)
-#define Flag63(N)     (Nodes_Ptr [N+2].pflag1)
-#define Flag64(N)     (Nodes_Ptr [N+2].pflag2)
+#define Flag40(N)     (Nodes_Ptr [N+2].U.K.in_list)
+#define Flag41(N)     (Nodes_Ptr [N+2].U.K.rewrite_sub)
+#define Flag42(N)     (Nodes_Ptr [N+2].U.K.rewrite_ins)
+#define Flag43(N)     (Nodes_Ptr [N+2].U.K.analyzed)
+#define Flag44(N)     (Nodes_Ptr [N+2].U.K.comes_from_source)
+#define Flag45(N)     (Nodes_Ptr [N+2].U.K.error_posted)
+#define Flag46(N)     (Nodes_Ptr [N+2].U.K.flag4)
+#define Flag47(N)     (Nodes_Ptr [N+2].U.K.flag5)
+#define Flag48(N)     (Nodes_Ptr [N+2].U.K.flag6)
+#define Flag49(N)     (Nodes_Ptr [N+2].U.K.flag7)
+#define Flag50(N)     (Nodes_Ptr [N+2].U.K.flag8)
+#define Flag51(N)     (Nodes_Ptr [N+2].U.K.flag9)
+#define Flag52(N)     (Nodes_Ptr [N+2].U.K.flag10)
+#define Flag53(N)     (Nodes_Ptr [N+2].U.K.flag11)
+#define Flag54(N)     (Nodes_Ptr [N+2].U.K.flag12)
+#define Flag55(N)     (Nodes_Ptr [N+2].U.K.flag13)
+#define Flag56(N)     (Nodes_Ptr [N+2].U.K.flag14)
+#define Flag57(N)     (Nodes_Ptr [N+2].U.K.flag15)
+#define Flag58(N)     (Nodes_Ptr [N+2].U.K.flag16)
+#define Flag59(N)     (Nodes_Ptr [N+2].U.K.flag17)
+#define Flag60(N)     (Nodes_Ptr [N+2].U.K.flag18)
+#define Flag61(N)     (Nodes_Ptr [N+1].U.K.pflag1)
+#define Flag62(N)     (Nodes_Ptr [N+1].U.K.pflag2)
+#define Flag63(N)     (Nodes_Ptr [N+2].U.K.pflag1)
+#define Flag64(N)     (Nodes_Ptr [N+2].U.K.pflag2)
 
-#define Flag65(N)     (Nodes_Ptr [N+2].U.fb.flag65)
-#define Flag66(N)     (Nodes_Ptr [N+2].U.fb.flag66)
-#define Flag67(N)     (Nodes_Ptr [N+2].U.fb.flag67)
-#define Flag68(N)     (Nodes_Ptr [N+2].U.fb.flag68)
-#define Flag69(N)     (Nodes_Ptr [N+2].U.fb.flag69)
-#define Flag70(N)     (Nodes_Ptr [N+2].U.fb.flag70)
-#define Flag71(N)     (Nodes_Ptr [N+2].U.fb.flag71)
-#define Flag72(N)     (Nodes_Ptr [N+2].U.fb.flag72)
+#define Flag65(N)     (Nodes_Ptr [N+2].U.NK.flag65)
+#define Flag66(N)     (Nodes_Ptr [N+2].U.NK.flag66)
+#define Flag67(N)     (Nodes_Ptr [N+2].U.NK.flag67)
+#define Flag68(N)     (Nodes_Ptr [N+2].U.NK.flag68)
+#define Flag69(N)     (Nodes_Ptr [N+2].U.NK.flag69)
+#define Flag70(N)     (Nodes_Ptr [N+2].U.NK.flag70)
+#define Flag71(N)     (Nodes_Ptr [N+2].U.NK.flag71)
+#define Flag72(N)     (Nodes_Ptr [N+2].U.NK.flag72)
 
 #define Flag73(N)     (Nodes_Ptr [N+2].V.EX.U.fw.flag73)
 #define Flag74(N)     (Nodes_Ptr [N+2].V.EX.U.fw.flag74)
@@ -451,28 +512,37 @@ extern Node_Id Parent		PROTO((Tree_Id));
 #define Flag127(N)     (Nodes_Ptr [N+3].V.EX.U.fw2.flag127)
 #define Flag128(N)     (Nodes_Ptr [N+3].V.EX.U.fw2.flag128)
 
-#define Flag129(N)     (Nodes_Ptr [N+3].in_list)
-#define Flag130(N)     (Nodes_Ptr [N+3].rewrite_sub)
-#define Flag131(N)     (Nodes_Ptr [N+3].rewrite_ins)
-#define Flag132(N)     (Nodes_Ptr [N+3].analyzed)
-#define Flag133(N)     (Nodes_Ptr [N+3].comes_from_source)
-#define Flag134(N)     (Nodes_Ptr [N+3].error_posted)
-#define Flag135(N)     (Nodes_Ptr [N+3].flag4)
-#define Flag136(N)     (Nodes_Ptr [N+3].flag5)
-#define Flag137(N)     (Nodes_Ptr [N+3].flag6)
-#define Flag138(N)     (Nodes_Ptr [N+3].flag7)
-#define Flag139(N)     (Nodes_Ptr [N+3].flag8)
-#define Flag140(N)     (Nodes_Ptr [N+3].flag9)
-#define Flag141(N)     (Nodes_Ptr [N+3].flag10)
-#define Flag142(N)     (Nodes_Ptr [N+3].flag11)
-#define Flag143(N)     (Nodes_Ptr [N+3].flag12)
-#define Flag144(N)     (Nodes_Ptr [N+3].flag13)
-#define Flag145(N)     (Nodes_Ptr [N+3].flag14)
-#define Flag146(N)     (Nodes_Ptr [N+3].flag15)
-#define Flag147(N)     (Nodes_Ptr [N+3].flag16)
-#define Flag148(N)     (Nodes_Ptr [N+3].flag17)
-#define Flag149(N)     (Nodes_Ptr [N+3].flag18)
-#define Flag150(N)     (Nodes_Ptr [N+3].pflag1)
-#define Flag151(N)     (Nodes_Ptr [N+3].pflag2)
+#define Flag129(N)     (Nodes_Ptr [N+3].U.K.in_list)
+#define Flag130(N)     (Nodes_Ptr [N+3].U.K.rewrite_sub)
+#define Flag131(N)     (Nodes_Ptr [N+3].U.K.rewrite_ins)
+#define Flag132(N)     (Nodes_Ptr [N+3].U.K.analyzed)
+#define Flag133(N)     (Nodes_Ptr [N+3].U.K.comes_from_source)
+#define Flag134(N)     (Nodes_Ptr [N+3].U.K.error_posted)
+#define Flag135(N)     (Nodes_Ptr [N+3].U.K.flag4)
+#define Flag136(N)     (Nodes_Ptr [N+3].U.K.flag5)
+#define Flag137(N)     (Nodes_Ptr [N+3].U.K.flag6)
+#define Flag138(N)     (Nodes_Ptr [N+3].U.K.flag7)
+#define Flag139(N)     (Nodes_Ptr [N+3].U.K.flag8)
+#define Flag140(N)     (Nodes_Ptr [N+3].U.K.flag9)
+#define Flag141(N)     (Nodes_Ptr [N+3].U.K.flag10)
+#define Flag142(N)     (Nodes_Ptr [N+3].U.K.flag11)
+#define Flag143(N)     (Nodes_Ptr [N+3].U.K.flag12)
+#define Flag144(N)     (Nodes_Ptr [N+3].U.K.flag13)
+#define Flag145(N)     (Nodes_Ptr [N+3].U.K.flag14)
+#define Flag146(N)     (Nodes_Ptr [N+3].U.K.flag15)
+#define Flag147(N)     (Nodes_Ptr [N+3].U.K.flag16)
+#define Flag148(N)     (Nodes_Ptr [N+3].U.K.flag17)
+#define Flag149(N)     (Nodes_Ptr [N+3].U.K.flag18)
+#define Flag150(N)     (Nodes_Ptr [N+3].U.K.pflag1)
+#define Flag151(N)     (Nodes_Ptr [N+3].U.K.pflag2)
+
+#define Flag152(N)     (Nodes_Ptr [N+3].V.EX.X.fw3.flag152)
+#define Flag153(N)     (Nodes_Ptr [N+3].V.EX.X.fw3.flag153)
+#define Flag154(N)     (Nodes_Ptr [N+3].V.EX.X.fw3.flag154)
+#define Flag155(N)     (Nodes_Ptr [N+3].V.EX.X.fw3.flag155)
+#define Flag156(N)     (Nodes_Ptr [N+3].V.EX.X.fw3.flag156)
+#define Flag157(N)     (Nodes_Ptr [N+3].V.EX.X.fw3.flag157)
+#define Flag158(N)     (Nodes_Ptr [N+3].V.EX.X.fw3.flag158)
+#define Flag159(N)     (Nodes_Ptr [N+3].V.EX.X.fw3.flag159)
 
 /* End of a-atree.h (C version of Atree package specification) */
