@@ -6,7 +6,7 @@
 /*                                                                          */
 /*                          C Implementation File                           */
 /*                                                                          */
-/*                            $Revision: 1.187 $                            */
+/*                            $Revision: 1.206 $                            */
 /*                                                                          */
 /*          Copyright (C) 1992-1997, Free Software Foundation, Inc.         */
 /*                                                                          */
@@ -83,6 +83,7 @@ tree raise_nodefer_decl;
 tree setjmp_decl;
 tree raise_constraint_error_decl;
 tree raise_program_error_decl;
+tree raise_storage_error_decl;
 
 tree integer_zero_node;
 tree integer_one_node;
@@ -463,18 +464,22 @@ pushdecl (decl)
     }
 
   /* For the declaration of a type, set its name if it either is not already
-     set or is an implicit type name.  We'd rather have the type named with a
-     real name and all the pointer types to the same object have the same
-     POINTER_TYPE node.  Code in this function in c-decl.c makes a copy
-     of the type node here, but that may cause us trouble with incomplete
-     types, so let's not try it (at least for now).  Ensure we don't set a
-     name if TYPE is not in the same obstack as DECL would have been placed. */
+     set, was set to an IDENTIFIER_NODE, indicating an internal name,
+     or if the previous type name was not derived from a source name.
+     We'd rather have the type named with a real name and all the pointer
+     types to the same object have the same POINTER_TYPE node.  Code in this
+     function in c-decl.c makes a copy of the type node here, but that may
+     cause us trouble with incomplete types, so let's not try it (at least
+     for now).  Also, ensure we don't set a name if TYPE is not in the same
+     obstack as DECL would have been placed. */
 
   if (TREE_CODE (decl) == TYPE_DECL
       && DECL_NAME (decl) != 0
       && (TYPE_NAME (TREE_TYPE (decl)) == 0
-	  || (TREE_CODE (TYPE_NAME (TREE_TYPE (decl))) == IDENTIFIER_NODE
-	      && *(IDENTIFIER_POINTER (TYPE_NAME (TREE_TYPE (decl)))) == 'T'))
+	  || TREE_CODE (TYPE_NAME (TREE_TYPE (decl))) == IDENTIFIER_NODE
+	  || (TREE_CODE (TYPE_NAME (TREE_TYPE (decl))) == TYPE_DECL
+	      && DECL_ARTIFICIAL (TYPE_NAME (TREE_TYPE (decl)))
+	      && ! DECL_ARTIFICIAL (decl)))
       && (TREE_PERMANENT (decl)
 	  || saveable_obstack == TYPE_OBSTACK (TREE_TYPE (decl))))
     TYPE_NAME (TREE_TYPE (decl)) = decl;
@@ -596,7 +601,7 @@ init_decl_processing ()
   jmpbuf_type
     = build_array_type (type_for_mode (Pmode, 0),
 			build_index_type (build_int_2 (5, 0)));
-  pushdecl (build_decl (TYPE_DECL, get_identifier ("jmpbuf_t"), jmpbuf_type));
+  pushdecl (build_decl (TYPE_DECL, get_identifier ("JMPBUF_T"), jmpbuf_type));
   jmpbuf_ptr_type = build_pointer_type (jmpbuf_type);
 
   /* Functions to get and set the jumpbuf pointer for the current thread.  */
@@ -671,6 +676,13 @@ init_decl_processing ()
        build_function_type (void_type_node, endlink),
        NULL_TREE, 0, 1, 1, NULL_PTR);
 
+  /* Likewise for __gnat_raise_storage_error.  */
+  raise_storage_error_decl
+    = create_subprog_decl
+      (get_identifier ("__gnat_raise_storage_error"), NULL_TREE,
+       build_function_type (void_type_node, endlink),
+       NULL_TREE, 0, 1, 1, NULL_PTR);
+
   /* Indicate that these never return.  */
   TREE_THIS_VOLATILE (raise_decl) = 1;
   TREE_THIS_VOLATILE (raise_nodefer_decl) = 1;
@@ -943,6 +955,10 @@ copy_type (type)
   new = copy_node (type);
   pop_obstacks ();
 
+  /* copy_node clears this field instead of copying it, because it is
+     aliased with TREE_CHAIN.  */
+  TYPE_STUB_DECL (new) = TYPE_STUB_DECL (type);
+
   TYPE_POINTER_TO (new) = 0;
   TYPE_REFERENCE_TO (new) = 0;
   TYPE_MAIN_VARIANT (new) = new;
@@ -985,14 +1001,11 @@ create_type_decl (type_name, type, attr_list)
      tree type;
      struct attrib *attr_list;
 {
-  tree type_decl = build_decl (TYPE_DECL, type_name, type);
+  tree type_decl = pushdecl (build_decl (TYPE_DECL, type_name, type));
   enum tree_code code = TREE_CODE (type);
 
   process_attributes (type_decl, attr_list);
 
-  /* Add this decl to the current binding level.  */
-  type_decl = pushdecl (type_decl);
-
   /* Pass type declaration information to the debugger unless this is an
      UNCONSTRAINED_ARRAY_TYPE, which the debugger does not support,
      and ENUMERAL_TYPE or RECORD_TYPE which is handled separately,
@@ -1042,10 +1055,7 @@ create_var_decl (var_name, asm_name, type, var_init, const_flag, public_flag,
 		   && TREE_CODE (TYPE_SIZE (type)) == INTEGER_CST
 		   && TREE_INT_CST_HIGH (TYPE_SIZE (type)) == 0
 		   && (TREE_INT_CST_LOW (TYPE_SIZE (type))
-		       <= GET_MODE_BITSIZE (DCmode))
-		   /* For the moment, don't do this for records
-		      due to the Assignment_OK flag.  */
-		   && ! AGGREGATE_TYPE_P (type))
+		       <= GET_MODE_BITSIZE (DCmode)))
 		  ? CONST_DECL : VAR_DECL, var_name, type);
   tree assign_init = 0;
 
@@ -1065,7 +1075,9 @@ create_var_decl (var_name, asm_name, type, var_init, const_flag, public_flag,
       add_pending_elaborations (var_decl, var_init);
       var_init = 0;
     }
-  else if (var_init != 0 && TREE_TYPE (var_init) != type)
+  else if (var_init != 0
+	   && (TYPE_MAIN_VARIANT (TREE_TYPE (var_init))
+	       != TYPE_MAIN_VARIANT (type)))
     assign_init = var_init, var_init = 0;
 
   DECL_COMMON   (var_decl) = 1;
@@ -1586,6 +1598,7 @@ type_for_size (precision, unsignedp)
 {
   tree t;
   int moment;
+  char type_name[20];
 
   if (precision <= MAX_BITS_PER_WORD
       && signed_and_unsigned_types[precision][unsignedp] != 0)
@@ -1603,6 +1616,12 @@ type_for_size (precision, unsignedp)
     t = signed_and_unsigned_types[precision][0]
       = make_signed_type (precision);
 
+  if (TYPE_NAME (t) == 0)
+    {
+      sprintf (type_name, "%sSIGNED_%d", unsignedp ? "UN" : "", precision);
+      TYPE_NAME (t) = get_identifier (type_name);
+    }
+
   pop_obstacks ();
   resume_momentary (moment);
 
@@ -1726,6 +1745,10 @@ max_size (exp, max_p)
 	case 2:
 	  if (code == RTL_EXPR)
 	    gigi_abort (407);
+	  else if (code == COMPOUND_EXPR)
+	    return max_size (TREE_OPERAND (exp, 1), max_p);
+	  else if (code == WITH_RECORD_EXPR)
+	    return exp;
 
 	  {
 	    tree lhs = max_size (TREE_OPERAND (exp, 0), max_p);
@@ -1734,11 +1757,19 @@ max_size (exp, max_p)
 
 	    /* Special-case wanting the maximum value of a MIN_EXPR.
 	       In that case, if one side overflows, return the other.
-	       sizetype is signed, but we know sizes are non-negative.  */
+	       sizetype is signed, but we know sizes are non-negative.
+	       Likewise, handle a MINUS_EXPR or PLUS_EXPR with the LHS
+	       overflowing or the maximum possible value and the RHS
+	       a variable.  */
 	    if (max_p && code == MIN_EXPR && TREE_OVERFLOW (rhs))
 	      return lhs;
 	    else if (max_p && code == MIN_EXPR && TREE_OVERFLOW (lhs))
 	      return rhs;
+	    else if ((code == MINUS_EXPR || code == PLUS_EXPR)
+		     && (TREE_OVERFLOW (lhs)
+			 || operand_equal_p (lhs, TYPE_MAX_VALUE (type), 0))
+		     && ! TREE_CONSTANT (rhs))
+	      return lhs;
 	    else
 	      return fold (build (code, type, lhs, rhs));
 	  }
@@ -1840,7 +1871,7 @@ build_vms_descriptor (type, mech, gnat_entity)
   tree record_type = make_node (RECORD_TYPE);
   tree field_list = 0;
   int descriptor_size = 32;	/* Always make 32 bit forms for now. */
-  int dtype;
+  int dtype = 0;
 
   /* If TYPE is an unconstrained array, use the underlying array type.  */
   if (TREE_CODE (type) == UNCONSTRAINED_ARRAY_TYPE)
@@ -1848,24 +1879,38 @@ build_vms_descriptor (type, mech, gnat_entity)
 
   if (INTEGRAL_TYPE_P (type))
     {
-      switch (GET_MODE_BITSIZE (TYPE_MODE (type)))
-	{
-	case 8:
-	  dtype = TREE_UNSIGNED (type) ? 2 : 6;
-	  break;
-	case 16:
-	  dtype = TREE_UNSIGNED (type) ? 3 : 7;
-	  break;
-	case 32:
-	  dtype = TREE_UNSIGNED (type) ? 4 : 8;
-	  break;
-	case 64:
-	  dtype = TREE_UNSIGNED (type) ? 5 : 9;
-	  break;
-	case 128:
-	  dtype = TREE_UNSIGNED (type) ? 25 : 26;
-	  break;
-	}
+      if (TYPE_VAX_FLOATING_POINT_P (type))
+	switch (TYPE_DIGITS_VALUE (type))
+	  {
+	  case 6:
+	    dtype = 10;
+	    break;
+	  case 9:
+	    dtype = 11;
+	    break;
+	  case 15:
+	    dtype = 27;
+	    break;
+	  }
+      else
+	switch (GET_MODE_BITSIZE (TYPE_MODE (type)))
+	  {
+	  case 8:
+	    dtype = TREE_UNSIGNED (type) ? 2 : 6;
+	    break;
+	  case 16:
+	    dtype = TREE_UNSIGNED (type) ? 3 : 7;
+	    break;
+	  case 32:
+	    dtype = TREE_UNSIGNED (type) ? 4 : 8;
+	    break;
+	  case 64:
+	    dtype = TREE_UNSIGNED (type) ? 5 : 9;
+	    break;
+	  case 128:
+	    dtype = TREE_UNSIGNED (type) ? 25 : 26;
+	    break;
+	  }
     }
   else if (FLOAT_TYPE_P (type))
     dtype = GET_MODE_BITSIZE (TYPE_MODE (type)) == 32 ? 52 : 53;
@@ -1873,8 +1918,6 @@ build_vms_descriptor (type, mech, gnat_entity)
 	   && TREE_CODE (TREE_TYPE (type)) == INTEGER_TYPE
 	   && TYPE_PRECISION (TREE_TYPE (type)) == CHAR_TYPE_SIZE)
     dtype = 14;
-  else
-    dtype = 0;
 
   if (mech == By_Descriptor)
     mech = By_Descriptor_S;
@@ -2054,8 +2097,24 @@ update_pointer_to (old_type, new_type)
       TYPE_POINTER_TO (new_type) = TREE_TYPE (new_type) = ptr;
       rest_of_type_compilation (ptr, global_bindings_p ());
 
+      /* Now handle updating the allocation record, what the thin pointer
+	 points to.  Update all pointers from the old record into the new
+	 one, update the types of the fields, and recompute the size.  */
+
       update_pointer_to (TYPE_OBJECT_RECORD_TYPE (old_type),
 			 TYPE_OBJECT_RECORD_TYPE (new_type));
+
+
+      TREE_TYPE (TYPE_FIELDS (TYPE_OBJECT_RECORD_TYPE (new_type)))
+	= TREE_TYPE (ptr_temp_type);
+      TREE_TYPE (TREE_CHAIN (TYPE_FIELDS (TYPE_OBJECT_RECORD_TYPE (new_type))))
+	= TREE_TYPE (TREE_TYPE (TYPE_FIELDS (ptr)));
+
+      TYPE_SIZE (TYPE_OBJECT_RECORD_TYPE (new_type))
+	= size_binop (MINUS_EXPR,
+		      TYPE_SIZE (TYPE_OBJECT_RECORD_TYPE (new_type)),
+		      DECL_FIELD_BITPOS
+		      (TYPE_FIELDS (TYPE_OBJECT_RECORD_TYPE (new_type))));
     }
 }
 
@@ -2152,6 +2211,46 @@ convert (type, expr)
   if (type == etype)
     return expr;
 
+  /* If the input type has padding, remove it by doing a component reference
+     to the field.  If the output type has padding, make a constructor
+     to build the record.  If both input and output have padding and are
+     of variable size, do this as an unchecked conversion.  */
+  if (ecode == RECORD_TYPE && code == RECORD_TYPE
+      && TYPE_IS_PADDING_P (type) && TYPE_IS_PADDING_P (etype)
+      && (! TREE_CONSTANT (TYPE_SIZE (type))
+	  || ! TREE_CONSTANT (TYPE_SIZE (etype))))
+    ;
+  else if (ecode == RECORD_TYPE && TYPE_IS_PADDING_P (etype))
+    {
+      /* If we have just converted to this padded type, just get
+	 the inner expression.  */
+      if (TREE_CODE (expr) == CONSTRUCTOR
+	  && CONSTRUCTOR_ELTS (expr) != 0
+	  && TREE_PURPOSE (CONSTRUCTOR_ELTS (expr)) == TYPE_FIELDS (etype))
+	return TREE_VALUE (CONSTRUCTOR_ELTS (expr));
+      else
+	return convert (type, build_component_ref (expr, NULL_TREE,
+						   TYPE_FIELDS (etype)));
+    }
+  else if (code == RECORD_TYPE && TYPE_IS_PADDING_P (type))
+    {
+      /* If we are just removing the padding from expr, convert the original
+	 object if we have variable size.  That will avoid the need
+	 for some variable-size temporaries.  */
+      if (TREE_CODE (expr) == COMPONENT_REF
+	  && TYPE_IS_PADDING_P (TREE_TYPE (TREE_OPERAND (expr, 0)))
+	  && ! TREE_CONSTANT (TYPE_SIZE (type)))
+	return convert (type, TREE_OPERAND (expr, 0));
+      else
+	return
+	  build_constructor (type,
+			     tree_cons (TYPE_FIELDS (type),
+					convert (TREE_TYPE
+						 (TYPE_FIELDS (type)),
+						 expr),
+					NULL_TREE));
+    }
+
   /* If the input is a biased type, adjust first.  */
   if (ecode == INTEGER_TYPE && TYPE_BIASED_REPRESENTATION_P (etype))
     return convert (type, fold (build (PLUS_EXPR, TREE_TYPE (etype),
@@ -2184,20 +2283,6 @@ convert (type, expr)
 				 convert (obj_type, expr), NULL_TREE)));
     }
 
-  /* If the input type has padding, remove it by doing a component reference
-     to the field.  If the output type has padding, make a constructor
-     to build the record.  */
-  if (ecode == RECORD_TYPE && TYPE_IS_PADDING_P (etype))
-    return convert (type, build_component_ref (expr, NULL_TREE,
-					       TYPE_FIELDS (etype)));
-  else if (code == RECORD_TYPE && TYPE_IS_PADDING_P (type))
-    return
-      build_constructor (type,
-			 tree_cons (TYPE_FIELDS (type),
-				    convert (TREE_TYPE (TYPE_FIELDS (type)),
-					     expr),
-				    NULL_TREE));
-
   /* There are some special cases of expressions that we process
      specially.  */
   switch (TREE_CODE (expr))
@@ -2217,13 +2302,18 @@ convert (type, expr)
     case CONSTRUCTOR:
       /* If we are converting a STRING_CST to another constrained array type,
 	 just make a new one in the proper type.  Likewise for a
-	 CONSTRUCTOR.  */
+	 CONSTRUCTOR.  But if the mode of the type is different, we must
+	 ensure a new RTL is made for the constant.  */
       if (code == ecode && AGGREGATE_TYPE_P (etype)
 	  && ! (TREE_CODE (TYPE_SIZE (etype)) == INTEGER_CST
 		&& TREE_CODE (TYPE_SIZE (type)) != INTEGER_CST))
 	{
 	  expr = copy_node (expr);
 	  TREE_TYPE (expr) = type;
+
+	  if (TYPE_MODE (type) != TYPE_MODE (etype))
+	    TREE_CST_RTL (expr) = 0;
+
 	  return expr;
 	}
       break;
@@ -2436,11 +2526,11 @@ unchecked_convert (type, expr)
 
   /* If both types types are integral just do a normal conversion.
      Likewise for a conversion to an unconstrained array.  */
-  if (((INTEGRAL_TYPE_P (type)
+  if ((((INTEGRAL_TYPE_P (type) && ! TYPE_VAX_FLOATING_POINT_P (type))
 	|| (TREE_CODE (type) == POINTER_TYPE && ! TYPE_THIN_POINTER_P (type))
 	|| (TREE_CODE (type) == RECORD_TYPE
 	    && TYPE_LEFT_JUSTIFIED_MODULAR_P (type)))
-       && (INTEGRAL_TYPE_P (etype)
+       && ((INTEGRAL_TYPE_P (etype) && ! TYPE_VAX_FLOATING_POINT_P (etype))
 	   || (TREE_CODE (etype) == POINTER_TYPE
 	       && ! TYPE_THIN_POINTER_P (etype))
 	   || (TREE_CODE (etype) == RECORD_TYPE
@@ -2496,7 +2586,7 @@ unchecked_convert (type, expr)
     {
       tree rec_type = make_node (RECORD_TYPE);
       tree field
-	= create_field_decl (get_identifier ("obj"), etype, rec_type,
+	= create_field_decl (get_identifier ("OBJ"), etype, rec_type,
 			     1, 0, 0);
 
       TYPE_FIELDS (rec_type) = field;
